scoretools.extend_measures_in_expr_and_apply_full_measure_tuplets
=================================================================

.. autofunction:: abjad.tools.scoretools.extend_measures_in_expr_and_apply_full_measure_tuplets.extend_measures_in_expr_and_apply_full_measure_tuplets
